# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .studio_evaluation_public import StudioEvaluationPublic
from .studio_llm_model_public import StudioLlmModelPublic
from .studio_optimizer_public import StudioOptimizerPublic
from .studio_prompt_public import StudioPromptPublic


class OptimizationStudioConfigPublic(UniversalBaseModel):
    dataset_name: str
    prompt: StudioPromptPublic
    llm_model: StudioLlmModelPublic
    evaluation: StudioEvaluationPublic
    optimizer: StudioOptimizerPublic

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
