# This file was auto-generated by Fern from our API Definition.

import typing

OptimizationWriteStatus = typing.Union[
    typing.Literal["running", "completed", "cancelled", "initialized", "error"], typing.Any
]
