# This file was auto-generated by Fern from our API Definition.

import typing

FeedbackScoreExperimentItemBulkWriteViewSource = typing.Union[typing.Literal["ui", "sdk", "online_scoring"], typing.Any]
